--[[**********************************************************
    * Name:      wxiscanttspico.lua
    * Purpose:   Sample for integrating an alternative tts
    *            engine as an Lua addon for wxIScan.
    * Author:    Daniel Nell (daniel.nell@nellresearch.de)
    * Created:   2010-10-31
    * Copyright: Daniel Nell (www.nellresearch.de)
    * License:   GPL
    **********************************************************
--]]



-- Do OCR via cuneiform using the given language and
-- read it out using libttspico and aplay.
--
function ReadOut( Language )
    -- Handle default parameter(s).
    if Language == nil then
        Language= "en"
    end

    -- Create a temporary file(name).
    local TempFileName= os.tmpname()

    -- Create temporary filename(s) from basename.
    local TempFileNameText= TempFileName .. ".txt"
    local TempFileNameWav= TempFileName .. ".wav"

    -- OCR commands for various languages.
    local OcrCmd=
    {
        ["de"]= "cuneiform -l ger -f text -o " .. TempFileNameText .. " " .. TempFileName;
        ["en"]= "cuneiform -l eng -f text -o " .. TempFileNameText .. " " .. TempFileName
    }

    -- Read out commands for various languages.
    local ReadOutCmd=
    {
        ["de"]= "sh -c 'pico2wave --wave=" .. TempFileNameWav .. " --lang=de-DE \"`iconv -f UTF-8 " .. TempFileNameText .. "`\"";
        ["en"]= "sh -c 'pico2wave --wave=" .. TempFileNameWav .. " --lang=en-US \"`iconv -f UTF-8 " .. TempFileNameText .. "`\""
    }

    -- Convert the image to a monochrome image.
    wxIScan.Image2Mono()

    -- Save the image to the given name (as TIFF file).
    wxIScan.SaveImage( TempFileName, "image/tiff" )

    -- Execute the OCR software and create a plain text file.
    wxIScan.Execute( OcrCmd[Language] )

    -- Read out the text file to a temporary WAV file.
    wxIScan.Execute( ReadOutCmd[Language] )

    -- Play the temporary WAV file (asynchronous).
    wxIScan.Execute( "aplay " .. TempFileNameWav, true, TempFileNameWav )

    -- Remove temporary files.
    os.remove( TempFileNameText )
    os.remove( TempFileName )
end
