/////////////////////////////////////////////////////////////////////////////
// Project:     wxIView
// Purpose:     Complex wxWidgets sample
// Name:        wxoptionsdialog.h
// Author:      Daniel Nell
// Created:     2006/02/16
// Copyright:   (c) Daniel Nell
// Licence:     wxWindows licence
// Modified by:
/////////////////////////////////////////////////////////////////////////////

#ifndef __WXOPTIONSDIALOG_H
#define __WXOPTIONSDIALOG_H

/////////////////////////////////////////////////////////////////////////////
//  Constants
//
#define WXOPTIONSDIALOGMAXOPTION   100
#define WXOPTIONSDIALOGIDOPTION    31101

/////////////////////////////////////////////////////////////////////////////
//  Forward declarations
//
class wxBoxSizer;
class wxCheckBox;
class wxStaticLine;

/////////////////////////////////////////////////////////////////////////////
//  class wxOptionBase
//
/// \brief The (abstract) option for an option dialog.
///
/// This class represents an (abstract) option used in an option
/// dialog.
class wxOptionBase
{
  public:
    /// Default constructor.
    wxOptionBase(){}

    /// Virtual destructor.
    virtual ~wxOptionBase(){};

  public:
    // Abstract member functions
    virtual bool AddToSizer( wxBoxSizer *poSizer ) = 0; ///< ...
    virtual void StoreValue() = 0;                      ///< ...
};

/////////////////////////////////////////////////////////////////////////////
//  class wxOptionStaticLine
//
/// \brief The static line pseudo option for an option dialog.
///
/// This class represents a static line object used in an
/// option dialog.
class wxOptionStaticLine : public wxOptionBase
{
  public:
    /// Default constructor.
    wxOptionStaticLine( wxWindow *poWindow );

  public:
    // Member functions
    virtual bool AddToSizer( wxBoxSizer *poSizer );     ///< ...
    virtual void StoreValue(){}                         ///< ...

  protected:
    // Member variables.
    wxStaticLine *m_poStaticLine;
};

/////////////////////////////////////////////////////////////////////////////
//  class wxOptionCheckBox
//
/// \brief The boolean option for an option dialog.
///
/// This class represents a boolean (checkbox) option used in an
/// option dialog.
class wxOptionCheckBox : public wxOptionBase
{
  public:
    /// Default constructor.
    wxOptionCheckBox( wxWindow *poWindow, int nId, const wxString &strText,
                      bool *pbValue );

  public:
    // Member functions
    virtual bool AddToSizer( wxBoxSizer *poSizer );     ///< ...
    virtual void StoreValue();                          ///< ...

  protected:
    // Member variables.
    bool *m_pbValue;                                    ///< ...
    wxCheckBox *m_poCheckBox;                           ///< ...
};

/////////////////////////////////////////////////////////////////////////////
//  class wxOptionTextBox
//
/// \brief The text input box for an option dialog.
///
/// This class represents a text (wxTextCtrl) option used
/// in an option dialog.
class wxOptionTextBox : public wxOptionBase
{
  public:
    /// Default constructor.
    wxOptionTextBox( wxWindow *poWindow, int nId, const wxString &strText,
                     wxString *pstrValue, int nWidth= 400 );

  public:
    // Member functions
    virtual bool AddToSizer( wxBoxSizer *poSizer );     ///< ...
    virtual void StoreValue();                          ///< ...

  protected:
    wxWindow *m_poWindow;                               ///< ...
    wxString m_strText;                                 ///< ...
    wxString *m_pstrValue;                              ///< ...
    wxTextCtrl *m_poTextCtrl;                           ///< ...
};

/////////////////////////////////////////////////////////////////////////////
//  class wxOptionsDialog
//
/// \brief The option dialog.
///
/// This class represents the application's options dialog.
class wxOptionsDialog : public wxDialog
{
  public:
    /// \brief Standard constructor
    ///
    /// \param poParentWindow       a pointer to parent window (the window owner).
    wxOptionsDialog( wxWindow *poParentWindow );

    /// Virtual destructor.
    virtual ~wxOptionsDialog();

  public:
    // Member functions
    virtual void SetupDialog();                             ///< Setup the dialog window.
    virtual bool AppendOption( wxOptionBase *poOption );    ///< Append the given option object to the options list.

  protected:
    void OnOk( wxCommandEvent& oEvent );                    ///< Handler for pressed OK button.

  protected:
    int m_nOptionCount;                                     ///< Number of option objects.
    wxOptionBase *m_apoOptions[WXOPTIONSDIALOGMAXOPTION];   ///< Array of option objects.

  private:
    // Any class wishing to process wxWindows events must use this macro.
    DECLARE_EVENT_TABLE()
};

#endif // __WXOPTIONSDIALOG_H
